CREATE SCHEMA [yahoo]
GO

CREATE TABLE [yahoo].[HistoricalPricesDaily] (
    [Symbol] [varchar](50) NOT NULL,
    [LoadDate] [date] NOT NULL,
    [LoadTime] [time](0) NOT NULL,
    [Date] [date] NOT NULL,
    [Open] [smallmoney] NULL,
    [High] [smallmoney] NULL,
    [Low] [smallmoney] NULL,
    [Close] [smallmoney] NULL,
    [Volume] [bigint] NULL,
    [UnAdjOpen] [smallmoney] NULL,
    [UnAdjHigh] [smallmoney] NULL,
    [UnAdjLow] [smallmoney] NULL,
    [UnAdjClose] [smallmoney] NULL,
  CONSTRAINT [PK_HistoricalPricesDaily_yahoo] PRIMARY KEY
(
    [Symbol],
    [Date],
    [LoadDate],
    [LoadTime]
)
)
GO

CREATE TABLE [yahoo].[HistoricalPricesWeekly] (
    [Symbol] [varchar](50) NOT NULL,
    [LoadDate] [date] NOT NULL,
    [LoadTime] [time](0) NOT NULL,
    [Date] [date] NOT NULL,
    [Open] [smallmoney] NULL,
    [High] [smallmoney] NULL,
    [Low] [smallmoney] NULL,
    [Close] [smallmoney] NULL,
    [Volume] [bigint] NULL,
    [UnAdjOpen] [smallmoney] NULL,
    [UnAdjHigh] [smallmoney] NULL,
    [UnAdjLow] [smallmoney] NULL,
    [UnAdjClose] [smallmoney] NULL,
  CONSTRAINT [PK_HistoricalPricesWeekly_yahoo] PRIMARY KEY
(
    [Symbol],
    [Date],
    [LoadDate],
    [LoadTime]
)
)
GO

CREATE TABLE [yahoo].[HistoricalPricesMonthly] (
    [Symbol] [varchar](50) NOT NULL,
    [LoadDate] [date] NOT NULL,
    [LoadTime] [time](0) NOT NULL,
    [Date] [date] NOT NULL,
    [Open] [smallmoney] NULL,
    [High] [smallmoney] NULL,
    [Low] [smallmoney] NULL,
    [Close] [smallmoney] NULL,
    [Volume] [bigint] NULL,
    [UnAdjOpen] [smallmoney] NULL,
    [UnAdjHigh] [smallmoney] NULL,
    [UnAdjLow] [smallmoney] NULL,
    [UnAdjClose] [smallmoney] NULL,
  CONSTRAINT [PK_HistoricalPricesMonthly_yahoo] PRIMARY KEY
(
    [Symbol],
    [Date],
    [LoadDate],
    [LoadTime]
)
)
GO

CREATE TABLE [yahoo].[IntradayPrices1m] (
    [Symbol] [varchar](50) NOT NULL,
    [LoadDate] [date] NOT NULL,
    [LoadTime] [time](0) NOT NULL,
    [Date] [datetime] NOT NULL,
    [Open] [smallmoney] NULL,
    [High] [smallmoney] NULL,
    [Low] [smallmoney] NULL,
    [Close] [smallmoney] NULL,
    [Volume] [int] NULL,
  CONSTRAINT [PK_IntradayPrices1m_yahoo] PRIMARY KEY
(
    [Symbol],
    [Date],
    [LoadDate],
    [LoadTime]
)
)
GO

CREATE TABLE [yahoo].[IntradayPrices5m] (
    [Symbol] [varchar](50) NOT NULL,
    [LoadDate] [date] NOT NULL,
    [LoadTime] [time](0) NOT NULL,
    [Date] [datetime] NOT NULL,
    [Open] [smallmoney] NULL,
    [High] [smallmoney] NULL,
    [Low] [smallmoney] NULL,
    [Close] [smallmoney] NULL,
    [Volume] [int] NULL,
  CONSTRAINT [PK_IntradayPrices5m_yahoo] PRIMARY KEY
(
    [Symbol],
    [Date],
    [LoadDate],
    [LoadTime]
)
)
GO

CREATE TABLE [yahoo].[IntradayPrices15m] (
    [Symbol] [varchar](50) NOT NULL,
    [LoadDate] [date] NOT NULL,
    [LoadTime] [time](0) NOT NULL,
    [Date] [datetime] NOT NULL,
    [Open] [smallmoney] NULL,
    [High] [smallmoney] NULL,
    [Low] [smallmoney] NULL,
    [Close] [smallmoney] NULL,
    [Volume] [int] NULL,
  CONSTRAINT [PK_IntradayPrices15m_yahoo] PRIMARY KEY
(
    [Symbol],
    [Date],
    [LoadDate],
    [LoadTime]
)
)
GO

CREATE TABLE [yahoo].[IntradayPrices60m] (
    [Symbol] [varchar](50) NOT NULL,
    [LoadDate] [date] NOT NULL,
    [LoadTime] [time](0) NOT NULL,
    [Date] [datetime] NOT NULL,
    [Open] [smallmoney] NULL,
    [High] [smallmoney] NULL,
    [Low] [smallmoney] NULL,
    [Close] [smallmoney] NULL,
    [Volume] [int] NULL,
  CONSTRAINT [PK_IntradayPrices60m_yahoo] PRIMARY KEY
(
    [Symbol],
    [Date],
    [LoadDate],
    [LoadTime]
)
)
GO

CREATE TABLE [yahoo].[OptionContracts] (
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [ContractName] [varchar](50) NOT NULL,
    [Symbol] [varchar](50) NOT NULL,
    [ExpDate] [date] NOT NULL,
    [Type] [char](1) NOT NULL,
    [Strike] [smallmoney] NOT NULL,
    [PairContractName] [varchar](50) NOT NULL,
  CONSTRAINT [PK_OptionContracts_yahoo] PRIMARY KEY ([ID]),
  CONSTRAINT [IX_OptionContracts_ContractName_yahoo] UNIQUE ([ContractName])
)
GO

CREATE TABLE [yahoo].[Options] (
    [OptionContractID] [int] NOT NULL,
    [LoadDate] [date] NOT NULL,
    [LoadTime] [time](0) NOT NULL,
    [MarketDate] [date] NULL,
    [MarketTime] [time](0) NULL,
    [Bid] [smallmoney] NULL,
    [Ask] [smallmoney] NULL,
    [Last] [smallmoney] NULL,
    [Change] [smallmoney] NULL,
    [ChangeInPercent] [float] NULL,
    [Volume] [int] NULL,
    [OpenInterest] [int] NULL,
    [ImpliedVolatility] [float] NULL,
  CONSTRAINT [PK_Options_yahoo] PRIMARY KEY
(
    [OptionContractID],
    [LoadDate],
    [LoadTime]
)
)
GO

CREATE TABLE [yahoo].[OptionTypes] (
    [OptionType] [char](1) NOT NULL,
    [Type] [varchar](4) NOT NULL,
  CONSTRAINT [PK_OptionTypes_yahoo] PRIMARY KEY ([OptionType]),
  CONSTRAINT [IX_OptionTypes_Type_yahoo] UNIQUE ([OptionType])
)
GO

ALTER TABLE [yahoo].[OptionContracts] ADD CONSTRAINT [FK_OptionContracts_OptionTypes_yahoo] FOREIGN KEY ([Type])
REFERENCES [yahoo].[OptionTypes] ([OptionType])
ON UPDATE CASCADE
ON DELETE CASCADE
GO

ALTER TABLE [yahoo].[Options] ADD CONSTRAINT [FK_Options_OptionContracts_yahoo] FOREIGN KEY ([OptionContractID])
REFERENCES [yahoo].[OptionContracts] ([ID])
ON UPDATE CASCADE
ON DELETE CASCADE
GO

INSERT [yahoo].[OptionTypes] ([OptionType], [Type]) VALUES (N'C', N'CALL')
INSERT [yahoo].[OptionTypes] ([OptionType], [Type]) VALUES (N'P', N'PUT')
GO

CREATE TABLE [yahoo].[AssetProfiles] (
    [Symbol] [varchar](50) NOT NULL,
    [LoadDate] [date] NOT NULL,
    [LoadTime] [time](0) NOT NULL,
    [MarketDate] [date] NULL,
    [MarketTime] [time](0) NULL,
    [address1] [nvarchar](255) NULL,
    [city] [nvarchar](50) NULL,
    [state] [nvarchar](50) NULL,
    [zip] [varchar](50) NULL,
    [country] [nvarchar](255) NULL,
    [phone] [varchar](50) NULL,
    [website] [varchar](50) NULL,
    [Sector] [varchar](50) NULL,
    [Industry] [varchar](50) NULL,
    [industrySymbol] [varchar](50) NULL,
    [longBusinessSummary] [nvarchar](max) NULL,
    [fullTimeEmployees] [int] NULL,
    [companyOfficers_0_name] [nvarchar](50) NULL,
    [companyOfficers_0_age] [tinyint] NULL,
    [companyOfficers_0_title] [nvarchar](50) NULL,
    [companyOfficers_0_fiscalYear] [int] NULL,
    [companyOfficers_0_totalPay] [int] NULL,
    [companyOfficers_0_totalPay_fmt] [varchar](50) NULL,
    [companyOfficers_0_exercisedValue] [int] NULL,
    [companyOfficers_0_exercisedValue_fmt] [varchar](50) NULL,
    [companyOfficers_0_unexercisedValue] [int] NULL,
    [companyOfficers_0_unexercisedValue_fmt] [varchar](50) NULL,
    [companyOfficers_1_name] [nvarchar](50) NULL,
    [companyOfficers_1_age] [tinyint] NULL,
    [companyOfficers_1_title] [nvarchar](50) NULL,
    [companyOfficers_1_fiscalYear] [int] NULL,
    [companyOfficers_1_totalPay] [int] NULL,
    [companyOfficers_1_totalPay_fmt] [varchar](50) NULL,
    [companyOfficers_1_exercisedValue] [int] NULL,
    [companyOfficers_1_exercisedValue_fmt] [varchar](50) NULL,
    [companyOfficers_1_unexercisedValue] [int] NULL,
    [companyOfficers_1_unexercisedValue_fmt] [varchar](50) NULL,
    [companyOfficers_2_name] [nvarchar](50) NULL,
    [companyOfficers_2_age] [tinyint] NULL,
    [companyOfficers_2_title] [nvarchar](50) NULL,
    [companyOfficers_2_fiscalYear] [int] NULL,
    [companyOfficers_2_totalPay] [int] NULL,
    [companyOfficers_2_totalPay_fmt] [varchar](50) NULL,
    [companyOfficers_2_exercisedValue] [int] NULL,
    [companyOfficers_2_exercisedValue_fmt] [varchar](50) NULL,
    [companyOfficers_2_unexercisedValue] [int] NULL,
    [companyOfficers_2_unexercisedValue_fmt] [varchar](50) NULL,
    [companyOfficers_3_age] [tinyint] NULL,
    [companyOfficers_3_title] [nvarchar](50) NULL,
    [companyOfficers_3_fiscalYear] [int] NULL,
    [companyOfficers_3_totalPay] [int] NULL,
    [companyOfficers_3_totalPay_fmt] [varchar](50) NULL,
    [companyOfficers_3_exercisedValue] [int] NULL,
    [companyOfficers_3_exercisedValue_fmt] [varchar](50) NULL,
    [companyOfficers_3_unexercisedValue] [int] NULL,
    [companyOfficers_3_unexercisedValue_fmt] [varchar](50) NULL,
    [auditRisk] [float] NULL,
    [boardRisk] [float] NULL,
    [compensationRisk] [float] NULL,
    [shareHolderRightsRisk] [float] NULL,
    [overallRisk] [float] NULL,
    [governanceEpochDate] [date] NULL,
    [compensationAsOfEpochDate] [date] NULL,
  CONSTRAINT [PK_AssetProfiles_yahoo] PRIMARY KEY (
    [Symbol],
    [LoadDate]
  )
)
GO

CREATE TABLE [yahoo].[QuoteSummary] (
    [Symbol] [varchar](50) NOT NULL,
    [LoadDate] [date] NOT NULL,
    [LoadTime] [time](0) NOT NULL,
    [MarketDate] [date] NULL,
    [MarketTime] [time](0) NULL,
    [forwardPE] [float] NULL,
    [forwardPE_fmt] [float] NULL,
    [profitMargins] [float] NULL,
    [profitMargins_fmt] [float] NULL,
    [floatShares] [bigint] NULL,
    [floatShares_fmt] [varchar](50) NULL,
    [sharesOutstanding] [bigint] NULL,
    [sharesOutstanding_fmt] [varchar](50) NULL,
    [sharesShort] [bigint] NULL,
    [sharesShort_fmt] [varchar](50) NULL,
    [sharesShortPriorMonth] [bigint] NULL,
    [sharesShortPriorMonth_fmt] [varchar](50) NULL,
    [heldPercentInsiders] [float] NULL,
    [heldPercentInsiders_fmt] [varchar](50) NULL,
    [heldPercentInstitutions] [float] NULL,
    [heldPercentInstitutions_fmt] [varchar](50) NULL,
    [shortRatio] [float] NULL,
    [shortRatio_fmt] [varchar](50) NULL,
    [shortPercentOfFloat] [float] NULL,
    [shortPercentOfFloat_fmt] [varchar](50) NULL,
    [beta] [float] NULL,
    [beta_fmt] [varchar](50) NULL,
    [bookValue] [float] NULL,
    [bookValue_fmt] [varchar](50) NULL,
    [priceToBook] [float] NULL,
    [priceToBook_fmt] [varchar](50) NULL,
    [lastFiscalYearEnd] [date] NULL,
    [lastFiscalYearEnd_fmt] [varchar](50) NULL,
    [nextFiscalYearEnd] datetime NULL,
    [nextFiscalYearEnd_fmt] [varchar](50) NULL,
    [mostRecentQuarter] datetime NULL,
    [mostRecentQuarter_fmt] [varchar](50) NULL,
    [earningsQuarterlyGrowth] [float] NULL,
    [earningsQuarterlyGrowth_fmt] [varchar](50) NULL,
    [netIncomeToCommon] [float] NULL,
    [netIncomeToCommon_fmt] [varchar](50) NULL,
    [trailingEps] [float] NULL,
    [trailingEps_fmt] [varchar](50) NULL,
    [forwardEps] [float] NULL,
    [forwardEps_fmt] [varchar](50) NULL,
    [pegRatio] [float] NULL,
    [pegRatio_fmt] [varchar](50) NULL,
    [lastSplitFactor] [nvarchar](50) NULL,
    [lastSplitDate] [date] NULL,
    [lastSplitDate_fmt] [varchar](50) NULL,
    [52WeekChange] [float] NULL,
    [52WeekChange_fmt] [varchar](50) NULL,
    [SandP52WeekChange] [float] NULL,
    [SandP52WeekChange_fmt] [varchar](50) NULL,
    [earnings_earningsDate_0] [date] NULL,
    [earnings_earningsDate_0_fmt] [varchar](50) NULL,
    [earnings_earningsAverage] [float] NULL,
    [earnings_earningsAverage_fmt] [varchar](50) NULL,
    [earnings_earningsLow] [float] NULL,
    [earnings_earningsLow_fmt] [varchar](50) NULL,
    [earnings_earningsHigh] [float] NULL,
    [earnings_earningsHigh_fmt] [varchar](50) NULL,
    [earnings_revenueAverage] [bigint] NULL,
    [earnings_revenueAverage_fmt] [varchar](50) NULL,
    [earnings_revenueLow] [bigint] NULL,
    [earnings_revenueLow_fmt] [varchar](50) NULL,
    [earnings_revenueHigh] [bigint] NULL,
    [earnings_revenueHigh_fmt] [varchar](50) NULL,
    [exDividendDate] [date] NULL,
    [exDividendDate_fmt] [varchar](50) NULL,
    [dividendDate] [date] NULL,
    [dividendDate_fmt] [varchar](50) NULL,
    [currentPrice] [float] NULL,
    [currentPrice_fmt] [varchar](50) NULL,
    [targetHighPrice] [float] NULL,
    [targetHighPrice_fmt] [varchar](50) NULL,
    [targetLowPrice] [int] NULL,
    [targetLowPrice_fmt] [int] NULL,
    [targetMeanPrice] [float] NULL,
    [targetMeanPrice_fmt] [varchar](50) NULL,
    [targetMedianPrice] [float] NULL,
    [targetMedianPrice_fmt] [varchar](50) NULL,
    [recommendationMean] [float] NULL,
    [recommendationMean_fmt] [varchar](50) NULL,
    [recommendationKey] [varchar](50) NULL,
    [numberOfAnalystOpinions] [int] NULL,
    [numberOfAnalystOpinions_fmt] [varchar](50) NULL,
    [totalCash] [bigint] NULL,
    [totalCash_fmt] [varchar](50) NULL,
    [totalCashPerShare] [float] NULL,
    [totalCashPerShare_fmt] [varchar](50) NULL,
    [ebitda] [bigint] NULL,
    [ebitda_fmt] [varchar](50) NULL,
    [totalDebt] [bigint] NULL,
    [totalDebt_fmt] [varchar](50) NULL,
    [quickRatio] [float] NULL,
    [quickRatio_fmt] [varchar](50) NULL,
    [currentRatio] [float] NULL,
    [currentRatio_fmt] [varchar](50) NULL,
    [totalRevenue] [bigint] NULL,
    [totalRevenue_fmt] [varchar](50) NULL,
    [debtToEquity] [float] NULL,
    [debtToEquity_fmt] [varchar](50) NULL,
    [revenuePerShare] [float] NULL,
    [revenuePerShare_fmt] [varchar](50) NULL,
    [returnOnAssets] [float] NULL,
    [returnOnAssets_fmt] [varchar](50) NULL,
    [returnOnEquity] [float] NULL,
    [returnOnEquity_fmt] [varchar](50) NULL,
    [grossProfits] [bigint] NULL,
    [grossProfits_fmt] [varchar](50) NULL,
    [freeCashflow] [bigint] NULL,
    [freeCashflow_fmt] [varchar](50) NULL,
    [operatingCashflow] [bigint] NULL,
    [operatingCashflow_fmt] [varchar](50) NULL,
    [earningsGrowth] [float] NULL,
    [earningsGrowth_fmt] [varchar](50) NULL,
    [revenueGrowth] [float] NULL,
    [revenueGrowth_fmt] [varchar](50) NULL,
    [grossMargins] [float] NULL,
    [grossMargins_fmt] [varchar](50) NULL,
    [ebitdaMargins] [float] NULL,
    [ebitdaMargins_fmt] [varchar](50) NULL,
    [operatingMargins] [float] NULL,
    [operatingMargins_fmt] [varchar](50) NULL,
  CONSTRAINT [PK_QuoteSummary_yahoo] PRIMARY KEY (
    [Symbol],
    [LoadDate],
    [LoadTime]
  )
)
GO

CREATE TABLE [yahoo].[QuoteSummaryETF] (
    [Symbol] [varchar](50) NOT NULL,
    [LoadDate] [date] NOT NULL,
    [LoadTime] [time](0) NOT NULL,
    [MarketDate] [date] NULL,
    [MarketTime] [time](0) NULL,
    [legalType] [varchar](50) NULL,
    [fundFamily] [nvarchar](255) NULL,
    [category] [varchar](50) NULL,
    [ytdReturn] [float] NULL,
    [ytdReturn_fmt] [varchar](50) NULL,
    [beta3Year] [float] NULL,
    [beta3Year_fmt] [varchar](50) NULL,
    [totalAssets] [bigint] NULL,
    [totalAssets_fmt] [varchar](50) NULL,
    [yield] [float] NULL,
    [yield_fmt] [varchar](50) NULL,
    [fundInceptionDate] [date] NULL,
    [fundInceptionDate_fmt] [varchar](50) NULL,
    [threeYearAverageReturn] [float] NULL,
    [threeYearAverageReturn_fmt] [varchar](50) NULL,
    [fiveYearAverageReturn] [float] NULL,
    [fiveYearAverageReturn_fmt] [varchar](50) NULL,
  CONSTRAINT [PK_QuoteSummaryETF_yahoo] PRIMARY KEY (
    [Symbol],
    [LoadDate],
    [LoadTime]
  )
)
GO
